# Changelog

All notable changes to this project will be documented in this file.

## [0.5.0] - 2017-08-21

- Basic functions for Keycloak API (well_know, token, userinfo, logout, certs,
  entitlement, instropect)

## [0.6.0] - 2017-08-23

- Added load authorization settings

## [0.7.0] - 2017-08-23

- Added polices

## [0.8.0] - 2017-08-23

- Added permissions

## [0.9.0] - 2017-09-05

- Added functions for Admin Keycloak API

## [0.10.0] - 2017-10-23

- Updated libraries versions
- Updated Docs

## [0.11.0] - 2017-12-12

- Changed Instropect RPT

## [0.12.0] - 2018-01-25

- Add groups functions
- Add Admin Tasks for user and client role management
- Function to trigger user sync from provider

## [0.12.1] - 2018-08-04

- Add get_idps
- Rework group functions

 ## [master]

 * Renamed `KeycloakOpenID.well_know` to `KeycloakOpenID.well_known`
 * Add `KeycloakOpenID.token_exchange` to support Token Exchange
